@@ -1,4 +1,6 @@
+use smol_str::SmolStr;
 use sourcemap::SourceMap;
+use std::rc::Rc;
 
 #[derive(Clone, PartialEq, Eq, Hash)]
 pub struct GenMapOption {
@@ -19,7 +21,7 @@ impl Default for GenMapOption {
 }
 
 pub trait Source {
-  fn map(&mut self, option: &GenMapOption) -> Option<SourceMap>;
+  fn map(&mut self, option: &GenMapOption) -> Option<Rc<SourceMap>>;
 
-  fn source(&mut self) -> String;
+  fn source(&mut self) -> SmolStr;
 }
